@@ -153,13 +153,22 @@ class EOPatch:
 
         return self.__setattr__(FeatureType(feature_type).value, value, feature_name=feature_name)
 
+    def __delitem__(self, feature):
+        """ Deletes the selected feature.
+
+        :param feature: EOPatch feature
+        :type feature: (FeatureType, str)
+        """
+        self._check_tuple_key(feature)
+        feature_type, feature_name = feature
+        del self[feature_type][feature_name]
+
     @staticmethod
     def _check_tuple_key(key):
         """ A helper function that checks a tuple, which should hold (feature_type, feature_name)
         """
         if len(key) != 2:
-            raise ValueError('Given element should be a feature_type or a tuple of (feature_type, feature_name),'
-                             'but {} found'.format(key))
+            raise ValueError(f'Given element should be a tuple of (feature_type, feature_name), but {key} found')
 
     def __eq__(self, other):
         """True if FeatureType attributes, bbox, and timestamps of both EOPatches are equal by value."""
@@ -235,10 +244,10 @@ class EOPatch:
         return '.'.join([cls.__module__.split('.')[0], cls.__name__])
 
     def __copy__(self, features=...):
-        """Returns a new EOPatch with shallow copies of given features.
+        """ Returns a new EOPatch with shallow copies of given features.
 
         :param features: A collection of features or feature types that will be copied into new EOPatch.
-        :type features: object supported by eolearn.core.utilities.FeatureParser class
+        :type features: object supported by the :class:`FeatureParser<eolearn.core.utilities.FeatureParser>`
         """
         if not features:  # For some reason deepcopy and copy pass {} by default
             features = ...
@@ -252,12 +261,12 @@ class EOPatch:
         return new_eopatch
 
     def __deepcopy__(self, memo=None, features=...):
-        """Returns a new EOPatch with deep copies of given features.
+        """ Returns a new EOPatch with deep copies of given features.
 
         :param memo: built-in parameter for memoization
         :type memo: dict
         :param features: A collection of features or feature types that will be copied into new EOPatch.
-        :type features: object supported by eolearn.core.utilities.FeatureParser class
+        :type features: object supported by the :class:`FeatureParser<eolearn.core.utilities.FeatureParser>`
         """
         if not features:  # For some reason deepcopy and copy pass {} by default
             features = ...
@@ -268,6 +277,21 @@ class EOPatch:
 
         return new_eopatch
 
+    def copy(self, features=..., deep=False):
+        """ Get a copy of the current `EOPatch`.
+
+        :param features: Features to be copied into a new `EOPatch`. By default all features will be copied.
+        :type features: object supported by the :class:`FeatureParser<eolearn.core.utilities.FeatureParser>`
+        :param deep: If `True` it will make a deep copy of all data inside the `EOPatch`. Otherwise only a shallow copy
+            of `EOPatch` will be made. Note that `BBOX` and `TIMESTAMP` will be copied even with a shallow copy.
+        :type deep: bool
+        :return: An EOPatch copy.
+        :rtype: EOPatch
+        """
+        if deep:
+            return self.__deepcopy__(features=features)
+        return self.__copy__(features=features)
+
     def remove_feature(self, feature_type, feature_name):
         """Removes the feature ``feature_name`` from dictionary of ``feature_type``.
 
@@ -715,6 +739,16 @@ class _FeatureDict(dict):
 
         return value
 
+    def __eq__(self, other):
+        """ Compares its content against a content of another feature type dictionary
+        """
+        return deep_eq(self, other)
+
+    def __ne__(self, other):
+        """ Compares its content against a content of another feature type dictionary
+        """
+        return not self.__eq__(other)
+
     def get_dict(self):
         """Returns a Python dictionary of features and value."""
         return dict(self)
