@@ -12,6 +12,7 @@ file in the root directory of this source tree.
 """
 
 import logging
+import warnings
 from collections import OrderedDict
 from logging import Filter
 
@@ -515,3 +516,29 @@ def constant_pad(X, multiple_of, up_down_rule='even', left_right_rule='even', pa
 def bgr_to_rgb(bgr):
     """Converts Blue, Green, Red to Red, Green, Blue."""
     return bgr[..., [2, 1, 0]]
+
+
+def renamed_and_deprecated(deprecated_class):
+    """ A class decorator that signals that the class has been renamed when initialized
+
+        Example of use:
+
+        .. code-block:: python
+
+            @renamed_and_deprecated
+            class OldNameForClass(NewNameForClass):
+                ''' Deprecated version of `NewNameForClass`
+                '''
+
+    """
+
+    def warn_and_init(self, *args, **kwargs):
+        warnings.warn(
+            f'The class {self.__class__.__name__} has been renamed to {self.__class__.__mro__[1].__name__}. '
+            'The old name is deprecated and will be removed in version 1.0',
+            DeprecationWarning
+        )
+        super(deprecated_class, self).__init__(*args, **kwargs)
+
+    deprecated_class.__init__ = warn_and_init
+    return deprecated_class
